import viteAngular from '@analogjs/vite-plugin-angular';
import { enableProdMode } from '@angular/core';
function getRenderer() {
    return {
        name: '@analogjs/astro-angular',
        clientEntrypoint: '@analogjs/astro-angular/client.js',
        serverEntrypoint: '@analogjs/astro-angular/server.js',
    };
}
function getViteConfiguration(vite) {
    return {
        optimizeDeps: {
            include: [
                '@angular/platform-browser',
                '@angular/core',
                '@analogjs/astro-angular/client.js',
            ],
            exclude: [
                '@angular/platform-server',
                '@analogjs/astro-angular/server.js',
            ],
        },
        /**
         *
         * Why I am casting viteAngular as any
         *
         * The vite angular plugins is shipped as commonjs, while this astro
         * integration is shipped using ESM and if you call the default
         * function, you get the following error: viteAngular is not a function.
         * Attempt to use ESM for the angular vite plugin broke something, hence
         * this workaround for now.
         *
         */
        plugins: [
            viteAngular.default(vite),
            {
                name: '@analogjs/astro-angular-platform-server',
                transform(code, id) {
                    if (id.includes('platform-server')) {
                        code = code.replace(/global\./g, 'globalThis.');
                        return {
                            code: code.replace('new xhr2.XMLHttpRequest', 'new (xhr2.default.XMLHttpRequest || xhr2.default)'),
                        };
                    }
                    return;
                },
            },
        ],
        ssr: {
            noExternal: ['@angular/**', '@analogjs/**'],
        },
    };
}
export default function (options) {
    return {
        name: '@analogjs/astro-angular',
        hooks: {
            'astro:config:setup': ({ addRenderer, config, isRestart, updateConfig, }) => {
                var _a;
                if (!isRestart && ((_a = config.markdown) === null || _a === void 0 ? void 0 : _a.syntaxHighlight) === 'shiki') {
                    config.markdown.syntaxHighlight = 'prism';
                }
                addRenderer(getRenderer());
                updateConfig({ vite: getViteConfiguration(options === null || options === void 0 ? void 0 : options.vite) });
            },
            'astro:config:done': ({ config }) => {
                if ('markdown' in config &&
                    config.markdown.syntaxHighlight === 'shiki') {
                    console.warn(`[warning] The Angular integration doesn't support Shiki syntax highlighting in MDX files. Overriding with Prism.\n
To disable this warning, set the syntaxHighlight option in your astro.config.mjs mdx() integration to 'prism' or false.`);
                }
            },
            'astro:build:setup': () => {
                enableProdMode();
            },
        },
    };
}
//# sourceMappingURL=index.js.map